@@ -11,7 +11,17 @@
 The Panther Python Config SDK defines dataclasses that represent various objects in a Panther instance
 """
 
+from panther_core import PantherEvent
 
-from .detection import *
+__all__ = [
+    "PantherEvent",
+    "testing",
+    "detection",
+    "query",
+]
 
-from .query import *
+from . import (
+    testing,
+    detection,
+    query,
+)
