@@ -8,13 +8,18 @@
 # coding=utf-8
 # *** WARNING: generated file
 import os
+import ast
 import json
 import types
 import base64
 import inspect
+import logging
+import textwrap
 import datetime
 import dataclasses
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Callable, Union, cast, Tuple
+
+from panther_core.snapshots import snapshot_func
 
 
 @dataclasses.dataclass(frozen=True)
@@ -38,9 +43,10 @@ def origin_factory() -> ConfigNodeOrigin:
     if not module:
         return ConfigNodeOrigin()
 
+    module_name = module.__name__ or "none"
     return ConfigNodeOrigin(
         pkg=module.__package__ or "none",
-        name=module.__name__ or "none",
+        name=f"{module_name}.{frame.function}",
     )
 
 
@@ -132,10 +138,9 @@ def to_intermediate(obj: Any) -> Any:
         return [*map(to_intermediate, obj)]
 
     if isinstance(obj, types.FunctionType):
+        snapshot, _ = snapshot_func(obj)
         return dict(
-            src=base64.b64encode(inspect.getsource(obj).encode("utf-8")).decode(
-                "utf-8"
-            ),
+            src=base64.b64encode(snapshot.encode("utf-8")).decode("utf-8"),
             name=obj.__name__,
         )
 
