@@ -20,6 +20,7 @@ from .. import _utilities
 
 __all__ = [
     "AnyFilter",
+    "AnyUnitTest",
     "DynamicStringField",
     "DynamicStringFieldOptions",
     "DynamicDestinations",
@@ -28,8 +29,8 @@ __all__ = [
     "AlertGroupingOptions",
     "PythonFilter",
     "PythonFilterOptions",
-    "_BaseUnitTest",
-    "_BaseUnitTestOptions",
+    "UnitTestMock",
+    "UnitTestMockOptions",
     "JSONUnitTest",
     "JSONUnitTestOptions",
     "Policy",
@@ -201,32 +202,51 @@ class PythonFilter(_utilities.ConfigNode):
 
 
 @dataclasses.dataclass
-class _BaseUnitTestOptions:
-    """Options dataclass for _BaseUnitTest. All arguments are marked optional."""
+class UnitTestMockOptions:
+    """Options dataclass for UnitTestMock. All arguments are marked optional.
+
+    - name -- name of the object to mock
+    - return_value -- string to assign as the return value for the mock
+    """
+
+    name: typing.Optional[str] = None
+
+    return_value: typing.Optional[str] = None
 
 
 @dataclasses.dataclass(frozen=True)
-class _BaseUnitTest(_utilities.ConfigNode):
-    """Base unit test"""
+class UnitTestMock(_utilities.ConfigNode):
+    """Mock for a unit test
+
+    - name -- name of the object to mock (required)
+    - return_value -- string to assign as the return value for the mock (required)
+    """
+
+    # required
+    name: str
+
+    # required
+    return_value: str
 
     # internal private methods
     def _typename(self) -> str:
-        return "_BaseUnitTest"
+        return "UnitTestMock"
 
     def _output_key(self) -> str:
         return ""
 
     def _fields(self) -> typing.List[str]:
-        return []
+        return ["name", "return_value"]
 
 
 @dataclasses.dataclass
 class JSONUnitTestOptions:
     """Options dataclass for JSONUnitTest. All arguments are marked optional.
 
-    - data -- json data
-    - expect_match -- should this event trigger the rule?
+    - data -- json string
+    - expect_match -- whether the data should match and trigger an alert
     - name -- name of the unit test
+    - mocks -- list of mocks to use in the test
     """
 
     data: typing.Optional[str] = None
@@ -235,14 +255,17 @@ class JSONUnitTestOptions:
 
     name: typing.Optional[str] = None
 
+    mocks: typing.Optional[typing.List[UnitTestMock]] = None
+
 
 @dataclasses.dataclass(frozen=True)
-class JSONUnitTest(_BaseUnitTest):
+class JSONUnitTest(_utilities.ConfigNode):
     """Unit test with json content
 
-    - data -- json data (required)
-    - expect_match -- should this event trigger the rule? (required)
+    - data -- json string (required)
+    - expect_match -- whether the data should match and trigger an alert (required)
     - name -- name of the unit test (required)
+    - mocks -- list of mocks to use in the test (optional, default: None)
     """
 
     # required
@@ -254,6 +277,9 @@ class JSONUnitTest(_BaseUnitTest):
     # required
     name: str
 
+    # optional
+    mocks: typing.Optional[typing.List[UnitTestMock]] = None
+
     # internal private methods
     def _typename(self) -> str:
         return "JSONUnitTest"
@@ -262,7 +288,7 @@ class JSONUnitTest(_BaseUnitTest):
         return ""
 
     def _fields(self) -> typing.List[str]:
-        return ["data", "expect_match", "name"]
+        return ["data", "expect_match", "name", "mocks"]
 
 
 @dataclasses.dataclass
@@ -329,7 +355,9 @@ class PolicyOptions:
     tags: typing.Optional[typing.Union[str, typing.List[str]]] = None
 
     unit_tests: typing.Optional[
-        typing.Union[_BaseUnitTest, typing.List[_BaseUnitTest]]
+        typing.Union[
+            typing.Union[JSONUnitTest], typing.List[typing.Union[JSONUnitTest]]
+        ]
     ] = None
 
 
@@ -412,7 +440,9 @@ class Policy(_utilities.ConfigNode):
 
     # optional
     unit_tests: typing.Optional[
-        typing.Union[_BaseUnitTest, typing.List[_BaseUnitTest]]
+        typing.Union[
+            typing.Union[JSONUnitTest], typing.List[typing.Union[JSONUnitTest]]
+        ]
     ] = None
 
     # internal private methods
@@ -511,7 +541,9 @@ class RuleOptions:
     threshold: typing.Optional[int] = None
 
     unit_tests: typing.Optional[
-        typing.Union[_BaseUnitTest, typing.List[_BaseUnitTest]]
+        typing.Union[
+            typing.Union[JSONUnitTest], typing.List[typing.Union[JSONUnitTest]]
+        ]
     ] = None
 
 
@@ -598,7 +630,9 @@ class Rule(_utilities.ConfigNode):
 
     # optional
     unit_tests: typing.Optional[
-        typing.Union[_BaseUnitTest, typing.List[_BaseUnitTest]]
+        typing.Union[
+            typing.Union[JSONUnitTest], typing.List[typing.Union[JSONUnitTest]]
+        ]
     ] = None
 
     # internal private methods
@@ -698,7 +732,9 @@ class ScheduledRuleOptions:
     threshold: typing.Optional[int] = None
 
     unit_tests: typing.Optional[
-        typing.Union[_BaseUnitTest, typing.List[_BaseUnitTest]]
+        typing.Union[
+            typing.Union[JSONUnitTest], typing.List[typing.Union[JSONUnitTest]]
+        ]
     ] = None
 
 
@@ -785,7 +821,9 @@ class ScheduledRule(_utilities.ConfigNode):
 
     # optional
     unit_tests: typing.Optional[
-        typing.Union[_BaseUnitTest, typing.List[_BaseUnitTest]]
+        typing.Union[
+            typing.Union[JSONUnitTest], typing.List[typing.Union[JSONUnitTest]]
+        ]
     ] = None
 
     # internal private methods
@@ -819,3 +857,4 @@ class ScheduledRule(_utilities.ConfigNode):
 
 
 AnyFilter = typing.Union[PythonFilter]
+AnyUnitTest = typing.Union[JSONUnitTest]
